@@ -75,19 +75,19 @@ def connect(url, motorcortex_types, param_tree, **kwargs):
     address, req_port, sub_port = parseUrl(url)
     # Open request connection
     req = Request(motorcortex_types, param_tree)
-    if not req.connect("%s:%s" % (address, req_port), **kwargs).get():
-        raise RuntimeError("Failed to establish request connection")
+    if not req.connect("{}:{}".format(address, req_port), **kwargs).get():
+        raise RuntimeError("Failed to establish request connection: {}:{}".format(address, req_port))
     # Open subscribe connection
     sub = Subscribe(req, motorcortex_types)
-    if not sub.connect("%s:%s" % (address, sub_port), **kwargs).get():
-        raise RuntimeError("Failed to establish subscribe connection")
+    if not sub.connect("{}:{}".format(address, sub_port), **kwargs).get():
+        raise RuntimeError("Failed to establish subscribe connection: {}:{}".format(address, sub_port))
     # Login
     login_reply = req.login(kwargs['login'], kwargs['password'])
     login_reply_msg = login_reply.get()
 
     motorcortex_msg = motorcortex_types.motorcortex()
     if not login_reply_msg.status == motorcortex_msg.OK:
-        raise RuntimeError("Login failed, status: %s" % login_reply_msg.status)
+        raise RuntimeError("Login failed, status: {}".format(login_reply_msg.status))
 
     # Requesting a parameter tree
     param_tree_reply = req.getParameterTree()
