@@ -7,6 +7,7 @@
 
 from __future__ import unicode_literals
 import motorcortex
+import logging
 import sys
 import os
 
@@ -116,7 +117,7 @@ class PrimitiveTypes(object):
             try:
                 value = self.__prepare(value)
             except ValueError:
-                print("Failed to encode: %s" % value)
+                logging.error(f"Failed to encode: {value}")
                 value = 0
 
         # if not list convert to list
@@ -187,17 +188,16 @@ class MessageTypes(object):
                 hash = load(data_file)
                 proto = proto_hash_pair['proto']
                 if ismodule(proto):
-                    print("Adding module: ", proto)
+                    logging.debug(f"Adding module: {proto}")
                     module_hash_pair_list.append(ModuleHashListPairContainer(proto, hash))
                 elif isinstance(proto, str):
-                    print("Loading module: ", proto)
+                    logging.debug(f"Loading module: {proto}")
+
                     name = os.path.splitext(os.path.basename(proto))[0]
                     module_hash_pair_list.append(
                         ModuleHashListPairContainer(importLibrary(str(name), proto), hash))
-
-                    # ModuleHashListPairContainer(SourceFileLoader(str(count), proto).load_module(), hash))
                 else:
-                    print("Failed to load module:", proto)
+                    logging.error(f"Failed to load module: {proto}")
                     return
                 count = count + 1
 
@@ -219,27 +219,6 @@ class MessageTypes(object):
                                 setattr(type, "decode_value", 0)
                                 self.__types_by_hash[hash] = type
 
-                # ClassName2Type = None
-                # if hasattr(module._sym_db, '_classes'):
-                #     ClassName2Type = module._sym_db._classes
-                # elif hasattr(module._sym_db, '_symbols'):
-                #     ClassName2Type = module._sym_db._symbols
-                # else:
-                #     print("Failed to find dictinary with type names!")
-                module
-
-                # try:
-                #     type = ClassName2Type[hash_type_pair['type']]
-                #     setattr(type, "decode_value", 0)
-                #     self.__types_by_hash[hash] = type
-                # except KeyError:
-                #     for msg in ClassName2Type:
-                #         type = ClassName2Type[msg]
-                #         msg_name = type.DESCRIPTOR.full_name
-                #         if (msg_name == hash_type_pair['type']):
-                #             setattr(type, "decode_value", 0)
-                #             self.__types_by_hash[hash] = type
-
             self.__loadPrimitives("DataType", module)
             self.__loadEnum("ParameterFlag", module, motorcortex)
             self.__loadEnum("ParameterType", module, motorcortex)
@@ -259,7 +238,7 @@ class MessageTypes(object):
             for module_hash in self.__module_hash_pair_list:
                 module_name = module_hash.module.DESCRIPTOR.package
                 if module_name == module_hash_pair.module.DESCRIPTOR.package:
-                    print ("Module %s already exists, replacing it with a new version" % (module_name))
+                    logging.warning(f"Module {module_name} already exists, replacing it with a new version")
                     self.__module_hash_pair_list.remove(module_hash)
 
         self.__module_hash_pair_list += module_hash_pair_list
@@ -274,7 +253,7 @@ class MessageTypes(object):
                 if hash > 0:
                     self.__hashes_by_name[name] = hash
                     self.__types_by_hash[hash] = PrimitiveTypes(name)
-            print("Loaded types from %s" % (name))
+            logging.debug(f"Loaded types from {name}")
         except:
             pass
 
@@ -283,7 +262,7 @@ class MessageTypes(object):
             enum = getattr(object, enum_name)
             for key in enum.DESCRIPTOR.values:
                 setattr(module, key.name, key.number)
-            print("Loaded enumerator %s" % (enum_name))
+            logging.debug(f"Loaded enumerator {enum_name}")
         except:
             pass
 
