@@ -120,7 +120,6 @@ class Subscription(object):
         self.__values = None
         self.__layout = None
         self.__is_complete = False
-        print("subscription created")
         self.__observer_list = []
         self.__pool = None
 
@@ -268,7 +267,7 @@ class Subscription(object):
                 if (offset + size) <= length:
                     timestamp = timespec._make(unpack_from('QQ', sub_msg, offset))
                     value = self.__decoder[counter].decode(sub_msg[offset + 16: offset + size],
-                                                           param.info.number_of_elements)
+                                                           size / param.info.data_size)
                     self.__values[counter] = Parameter(timestamp, value)
 
                 counter += 1
@@ -293,7 +292,7 @@ class Subscription(object):
 
                 if (offset + size) <= length:
                     value = self.__decoder[counter].decode(sub_msg[offset: offset + size],
-                                                           param.info.number_of_elements)
+                                                           size / param.info.data_size)
                     self.__values[counter] = Parameter(timestamp, value)
 
                 counter += 1
